summaryrefslogtreecommitdiffstats
path: root/branches/sca-equinox/modules/host-rmi/src/main/java/org/apache/tuscany/sca/host/rmi/RMIHost.java
diff options
context:
space:
mode:
authorjsdelfino <jsdelfino@13f79535-47bb-0310-9956-ffa450edef68>2008-09-29 00:50:22 +0000
committerjsdelfino <jsdelfino@13f79535-47bb-0310-9956-ffa450edef68>2008-09-29 00:50:22 +0000
commit2a7966363348acb2c6f6ad6eaa2308fd4da1f1ae (patch)
tree60890a3079724b0b7752c2997102e0b9e487ea15 /branches/sca-equinox/modules/host-rmi/src/main/java/org/apache/tuscany/sca/host/rmi/RMIHost.java
parent4f70240f137fdb1bfe4f5aeb26b664162310958e (diff)
Ported from trunk and simplified. Support the rmi:// uri for binding.rmi.
git-svn-id: http://svn.us.apache.org/repos/asf/tuscany@699932 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'branches/sca-equinox/modules/host-rmi/src/main/java/org/apache/tuscany/sca/host/rmi/RMIHost.java')
-rw-r--r--branches/sca-equinox/modules/host-rmi/src/main/java/org/apache/tuscany/sca/host/rmi/RMIHost.java41
1 files changed, 6 insertions, 35 deletions
diff --git a/branches/sca-equinox/modules/host-rmi/src/main/java/org/apache/tuscany/sca/host/rmi/RMIHost.java b/branches/sca-equinox/modules/host-rmi/src/main/java/org/apache/tuscany/sca/host/rmi/RMIHost.java
index 59377de22a..b95b91f003 100644
--- a/branches/sca-equinox/modules/host-rmi/src/main/java/org/apache/tuscany/sca/host/rmi/RMIHost.java
+++ b/branches/sca-equinox/modules/host-rmi/src/main/java/org/apache/tuscany/sca/host/rmi/RMIHost.java
@@ -32,59 +32,30 @@ public interface RMIHost {
/**
* Register an RMI service with the given name and port
*
* @param serviceName against which the server is to be registered
* @param port the port against which the server is to be registered
* @param serviceObject the server object to be registered
* @throws RMIHostException
* @throws RMIHostRuntimeException
*/
- void registerService(String serviceName, int port, Remote serviceObject) throws RMIHostException,
- RMIHostRuntimeException;
-
- /**
- * Register an RMI service with the given name and default port (1099)
- *
- * @param serviceName serviceName against which the server is to be registered
- * @param serviceObject the server object to be registered
- * @throws RMIHostException
- * @throws RMIHostRuntimeException
- */
- void registerService(String serviceName, Remote serviceObject) throws RMIHostException,
- RMIHostRuntimeException;
+ void registerService(String uri, Remote serviceObject) throws RMIHostException, RMIHostRuntimeException;
/**
* Unregister a service registered under the given service name and port number
*
- * @param serviceName serviceName against which the server is to be registered
- * @param port the port against which the server is to be registered
+ * @param uri the URI of the server
* @throws RMIHostException
* @throws RMIHostRuntimeException
*/
- void unregisterService(String serviceName, int port) throws RMIHostException,
- RMIHostRuntimeException;
-
- /**
- * Unregister a service registered under the given service name and default port number (1099)
- *
- * @param serviceName the name of the service that has to be unregistered
- * @throws RMIHostException
- * @throws RMIHostRuntimeException
- */
- void unregisterService(String serviceName) throws RMIHostException,
- RMIHostRuntimeException;
-
+ void unregisterService(String uri) throws RMIHostException, RMIHostRuntimeException;
/**
* find a remote service hosted on the given host, port and service name
*
- * @param host the name of the host on which the RMI service to be unregistered is running
- * @param port the port against which the server is to be unregistered is running
- * @param svcName serviceName against which the server is to be unregistered is running
+ * @param uri the URI of the service
* @return the RMI server object
* @throws RMIHostException
* @throws RMIHostRuntimeException
*/
- Remote findService(String host, String port, String svcName) throws RMIHostException,
- RMIHostRuntimeException;
+ Remote findService(String uri) throws RMIHostException, RMIHostRuntimeException;
}
@@ -32,59 +32,30 @@ public interface RMIHost {
* Register an RMI service with the given name and port
*
- * @param serviceName against which the server is to be registered
- * @param port the port against which the server is to be registered
+ * @param uri the URI against which the server is to be registered
* @param serviceObject the server object to be registered
* @throws RMIHostException